SystemOrganization addCategory: #ConfigurationOfSlot!

Object subclass: #ConfigurationOfSlot
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSlot'!

!ConfigurationOfSlot commentStamp: '<historical>' prior: 0!
Metacello configuration for Slot project 

See:
http://scg.unibe.ch/archive/papers/Verw11bFlexibleObjectLayouts.pdf!

!ConfigurationOfSlot class methodsFor: 'development support' stamp: 'MartinDias 3/25/2013 23:16'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSlot class methodsFor: 'private' stamp: 'MartinDias 3/25/2013 23:16'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSlot class methodsFor: 'private' stamp: 'MartinDias 3/25/2013 23:16'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSlot class methodsFor: 'private' stamp: 'MartinDias 3/25/2013 23:16'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSlot class methodsFor: 'metacello tool support' stamp: 'MartinDias 3/25/2013 23:16'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSlot class methodsFor: 'loading' stamp: 'MartinDias 3/25/2013 23:16'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSlot class methodsFor: 'loading' stamp: 'MartinDias 3/25/2013 23:16'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSlot class methodsFor: 'loading' stamp: 'MartinDias 3/25/2013 23:16'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSlot class methodsFor: 'accessing' stamp: 'MartinDias 3/25/2013 23:16'!
project

	^self new project! !

!ConfigurationOfSlot class methodsFor: 'development support' stamp: 'MartinDias 3/25/2013 23:16'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSlot methodsFor: 'baselines' stamp: 'MartinDias 3/26/2013 08:36'!
baseline100: spec 
	<version: '1.0-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/PharoTaskForces'.    
			spec
				package: 'Slot' with: [ spec postLoadDoIt: #spreadSlots ];
				package: 'SlotTests' with: [ spec requires: 'Slot' ];
				package: 'SlotsClassBuilderIntegration' with: [ spec requires: 'Slot' ].
                spec
                        group: 'default' with: #('Core Tests');
                        group: 'Core' with: #('Slot');
                        group: 'Tests' with: #('SlotTests'). ].! !

!ConfigurationOfSlot methodsFor: 'accessing' stamp: 'MartinDias 3/25/2013 23:16'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfSlot methodsFor: 'accessing' stamp: 'MartinDias 3/25/2013 23:16'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSlot methodsFor: 'post-load actions' stamp: 'MartinDias 3/25/2013 23:29'!
spreadSlots
	(Smalltalk classNamed: #SlotVirus) spread! !
